#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
@File    :   __init__.py
@Time    :   2025/12/16
@Author  :   Wei Lindong
@Version :   1.0
@Desc    :   Configuration files for OpenArmX driver
'''

# This package contains configuration files
# Configuration is loaded automatically by the Arm class
